@@ -30,6 +30,24 @@ impl Nonce {
 
     /// Convert a big-endian representation of the nonce
     pub fn from_bytes(bytes: &[u8; Self::BYTES]) -> CtOption<Self> {
-        scalar_from_bytes(bytes).map(|s| Self(s))
+        scalar_from_bytes(bytes).map(Self)
+    }
+}
+
+#[cfg(test)]
+mod test {
+    use crate::lib::Nonce;
+    use rand::thread_rng;
+
+    #[test]
+    fn test_nonce() {
+        let h = [0_u8; 32];
+        let n = Nonce::hash(h);
+        let nr = Nonce::random(thread_rng());
+        assert_ne!(n, nr);
+
+        let nb = n.to_bytes();
+        let n2 = Nonce::from_bytes(&nb).unwrap();
+        assert_eq!(n, n2);
     }
 }
